searchNodes=[{"type":"module","title":"GrowthBook.DecryptionUtils","doc":"Utilities for decrypting encrypted features from GrowthBook API. Uses AES-CBC with PKCS7 padding.","ref":"GrowthBook.DecryptionUtils.html"},{"type":"function","title":"GrowthBook.DecryptionUtils.decrypt/2","doc":"Decrypts an encrypted payload using the provided decryption key. The payload should be in the format &quot;iv.ciphertext&quot; where both parts are base64 encoded. Returns {:ok, decrypted_string} on success or {:error, reason} on failure.","ref":"GrowthBook.DecryptionUtils.html#decrypt/2"},{"type":"module","title":"GrowthBook.FeatureRepository","doc":"Repository for fetching and caching features from a GrowthBook API endpoint.","ref":"GrowthBook.FeatureRepository.html"},{"type":"function","title":"GrowthBook.FeatureRepository.await_initialization/2","doc":"","ref":"GrowthBook.FeatureRepository.html#await_initialization/2"},{"type":"function","title":"GrowthBook.FeatureRepository.child_spec/1","doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"GrowthBook.FeatureRepository.html#child_spec/1"},{"type":"function","title":"GrowthBook.FeatureRepository.get_features/0","doc":"","ref":"GrowthBook.FeatureRepository.html#get_features/0"},{"type":"function","title":"GrowthBook.FeatureRepository.get_latest_features/0","doc":"","ref":"GrowthBook.FeatureRepository.html#get_latest_features/0"},{"type":"function","title":"GrowthBook.FeatureRepository.refresh/0","doc":"","ref":"GrowthBook.FeatureRepository.html#refresh/0"},{"type":"function","title":"GrowthBook.FeatureRepository.start_link/1","doc":"","ref":"GrowthBook.FeatureRepository.html#start_link/1"},{"type":"module","title":"GrowthBook","doc":"GrowthBook is a GrowthBook SDK for Elixir/OTP. This SDK follows the guidelines set out in GrowthBook's documentation , and the API is tested on conformance with the test cases from the JS SDK. To ensure an Elixir-friendly API, the implementation deviates from the official SDK in the following ways: Instead of tuple-lists, this library uses actual tuples Comparisons with undefined are implemented by using :undefined Function names are converted to snake_case , and is_ prefix is replaced with a ? suffix Instead of classes, a Context struct is used (similar to %Plug.Conn{} in plug ) What is GrowthBook? GrowthBook is an open source A/B testing platform. The platform works significantly different from other A/B testing platforms, most notably: it is language agnostic. Clients by default work offline, and manage their own data. This means that you are free to implement A/B tests server-side, or client-side without worrying about things like &quot;anti-flicker&quot; scripts, or the added latency of JS embeds. Furthermore, GrowthBook supports both experiments (A/B tests and multivariate tests) and feature flags. Because all logic to run experiments and feature flags is contained in the library, there is virtually no added latency to running experiments or using feature flags. Installation Add growthbook to your list of dependencies in mix.exs : def deps do [ { :growthbook , &quot;~&gt; 0.2&quot; } ] end Usage # Create a context, which can be reused for multiple users # Approach 1: Manual Feature Configuration features_config = Jason . decode! ( &quot;&quot;&quot; { &quot;features&quot;: { &quot;send-reminder&quot;: { &quot;defaultValue&quot;: false, &quot;rules&quot;: [{ &quot;condition&quot;: { &quot;browser&quot;: &quot;chrome&quot; }, &quot;force&quot;: true }] }, &quot;add-to-cart-btn-color&quot;: { &quot;rules&quot;: [{ &quot;variations&quot;: [{ &quot;color&quot;: &quot;red&quot; }, { &quot;color&quot;: &quot;green&quot; }] }] } } } &quot;&quot;&quot; ) features = GrowthBook.Config . features_from_config ( features_config ) context = GrowthBook . build_context ( %{ &quot;id&quot; =&gt; &quot;12345&quot; , &quot;country_code&quot; =&gt; &quot;NL&quot; , &quot;browser&quot; =&gt; &quot;chrome&quot; } , features # Explicitly provide features ) # Approach 2: Auto-refreshing Features case GrowthBook . init ( client_key : &quot;key_prod_123...&quot; , api_host : &quot;https://cdn.growthbook.io&quot; , decryption_key : &quot;key_123...&quot; , swr_ttl_seconds : 60 , on_refresh : fn features -&gt; Logger . info ( &quot;Features refreshed: \#{ map_size ( features ) } available&quot; ) MyApp.FeatureNotifier . features_updated ( features ) end ) do { :ok , :initialized } -&gt; # Features loaded successfully # Start using GrowthBook... { :error , reason } -&gt; # Handle error # Handle initialization failure... end # Create context that automatically uses latest features context = GrowthBook . build_context ( %{ &quot;id&quot; =&gt; &quot;12345&quot; , &quot;country_code&quot; =&gt; &quot;NL&quot; , &quot;browser&quot; =&gt; &quot;chrome&quot; } ) # Usage is the same for both approaches: # Use a feature toggle if GrowthBook . feature ( context , &quot;send-reminder&quot; ) . on? do Logger . info ( &quot;Sending reminder&quot; ) end # Use a feature&#39;s value color = GrowthBook . feature ( context , &quot;add-to-cart-btn-color&quot; ) . value [ &quot;color&quot; ] Logger . info ( &quot;Color: &quot; &lt;&gt; color ) # Run an inline experiment if GrowthBook . run ( context , % GrowthBook.Experiment { key : &quot;checkout-v2&quot; , active? : true , coverage : 1 , variations : [ 1 , 2 ] } ) . in_experiment? do Logger . info ( &quot;In experiment&quot; ) end Auto-Refresh Features GrowthBook now supports automatic feature refreshing from your GrowthBook API. Instead of manually managing features, you can initialize GrowthBook with your API credentials. Core Components GenServer-Based Repository: Implemented as a GenServer that maintains feature state in memory (with stale-while-revalidate (SWR) caching strategy) that handles fetching, caching of features and refresh cycles based on configuration. # Initialize GrowthBook with auto-refresh case GrowthBook . init ( client_key : &quot;key_prod_123...&quot; , api_host : &quot;https://cdn.growthbook.io&quot; , decryption_key : &quot;key_123...&quot; , # Optional: Required for encrypted features swr_ttl_seconds : 60 , # Optional: Default is 60 seconds refresh_strategy : :periodic , # Optional: :periodic (default) or :manual on_refresh : fn features -&gt; # Optional: Callback when features are refreshed Logger . info ( &quot;Features refreshed: \#{ map_size ( features ) } available&quot; ) # Notify your application about new features MyApp.FeatureNotifier . features_updated ( features ) end ) do { :ok , :initialized } -&gt; # Features loaded successfully # Start using GrowthBook... { :error , reason } -&gt; # Handle error # Handle initialization failure... end # Create context that automatically uses latest features context = GrowthBook . build_context ( %{ &quot;id&quot; =&gt; &quot;12345&quot; , &quot;country_code&quot; =&gt; &quot;NL&quot; , &quot;browser&quot; =&gt; &quot;chrome&quot; } ) # Features will automatically refresh in the background # All feature evaluations will use the latest features if GrowthBook . feature ( context , &quot;send-reminder&quot; ) . on? do Logger . info ( &quot;Sending reminder&quot; ) end Refresh Strategies The SDK supports two refresh strategies: :periodic (default): Features are automatically refreshed in the background based on the TTL. :manual : Features are only refreshed when explicitly called with GrowthBook.FeatureRepository.refresh() . Shutting Down When your application is shutting down or you no longer need the feature repository, stop it properly to release resources: # Stops the FeatureRepository GenServer GenServer . stop ( GrowthBook.FeatureRepository ) Supervision Since the FeatureRepository is a GenServer, it's recommended to add it to your application's supervision tree for proper lifecycle management: # In your application.ex def start ( _type , _args ) do children = [ # Other children... # Add GrowthBook FeatureRepository to supervision tree { GrowthBook.FeatureRepository , client_key : &quot;key_prod_123...&quot; , api_host : &quot;https://cdn.growthbook.io&quot; , # Add other options as needed } ] opts = [ strategy : :one_for_one , name : MyApp.Supervisor ] Supervisor . start_link ( children , opts ) # Then initialize GrowthBook case GrowthBook.FeatureRepository . await_initialization ( GrowthBook.FeatureRepository , 5000 ) do :ok -&gt; Logger . info ( &quot;GrowthBook features initialized successfully&quot; ) { :error , reason } -&gt; Logger . error ( &quot;Failed to initialize GrowthBook features: \#{ reason } &quot; ) end { :ok , self ( ) } end Key improvements: Auto-refresh : Features automatically refresh from your GrowthBook API Encryption : Support for encrypted feature payloads Callbacks : Get notified when features are updated Resilient : Keeps existing features on API errors Configurable : Control refresh intervals and strategies License This library is MIT licensed. See the LICENSE file in this repository for details.","ref":"GrowthBook.html"},{"type":"function","title":"GrowthBook.build_context/2","doc":"Build a context with the given attributes and features. If features are not provided, it will use the FeatureRepository to always get the latest features.","ref":"GrowthBook.html#build_context/2"},{"type":"function","title":"GrowthBook.feature/3","doc":"Determine feature state for a given context This function takes a context and a feature key, and returns a GrowthBook.FeatureResult struct.","ref":"GrowthBook.html#feature/3"},{"type":"function","title":"GrowthBook.feature_value/3","doc":"Get a feature's value with a default fallback This is a convenience function that calls GrowthBook.feature/2 and returns the value, or the provided default if the feature isn't found or its value is nil. Examples iex&gt; GrowthBook . feature_value ( context , &quot;my-feature&quot; , false ) true iex&gt; GrowthBook . feature_value ( context , &quot;unknown-feature&quot; , &quot;default&quot; ) &quot;default&quot;","ref":"GrowthBook.html#feature_value/3"},{"type":"function","title":"GrowthBook.init/1","doc":"Initialize GrowthBook with the feature repository configuration. Returns {:ok, :initialized} if initialization succeeds with features loaded, {:error, reason} otherwise. Options :client_key - Required. The API client key :api_host - Required. The GrowthBook API host :decryption_key - Optional. Key for decrypting feature payloads :swr_ttl_seconds - Optional. Cache TTL in seconds (default: 60) :refresh_strategy - Optional. Either :periodic or :manual (default: :periodic) :on_refresh - Optional. Function to call when features are refreshed :initialization_timeout - Optional. Timeout in ms for initial feature fetch (default: 5000)","ref":"GrowthBook.html#init/1"},{"type":"function","title":"GrowthBook.run/4","doc":"Run an experiment for the given context This function takes a context and an experiment, and returns an GrowthBook.ExperimentResult struct.","ref":"GrowthBook.html#run/4"},{"type":"type","title":"GrowthBook.bucket_range/0","doc":"Bucket range A tuple that describes a range of the numberline between 0 and 1 . The tuple has 2 parts, both floats - the start of the range and the end. For example: { 0.3 , 0.7 }","ref":"GrowthBook.html#t:bucket_range/0"},{"type":"type","title":"GrowthBook.feature_key/0","doc":"Feature key A key for a feature. This is a string that references a feature.","ref":"GrowthBook.html#t:feature_key/0"},{"type":"type","title":"GrowthBook.init_result/0","doc":"","ref":"GrowthBook.html#t:init_result/0"},{"type":"type","title":"GrowthBook.namespace/0","doc":"Namespace A tuple that specifies what part of a namespace an experiment includes. If two experiments are in the same namespace and their ranges don't overlap, they wil be mutually exclusive. The tuple has 3 parts: The namespace id ( String.t() ) The beginning of the range ( float() , between 0 and 1 ) The end of the range ( float() , between 0 and 1 ) For example: { &quot;namespace1&quot; , 0 , 0.5 }","ref":"GrowthBook.html#t:namespace/0"},{"type":"module","title":"GrowthBook.Config","doc":"A set of helper functions to convert config maps to structs. This module is used to convert the configuration maps that are retrieved from GrowthBook's API (or your local cache) to values that can be used directly with the GrowthBook.Context module.","ref":"GrowthBook.Config.html"},{"type":"function","title":"GrowthBook.Config.experiment_from_config/1","doc":"Converts experiment configuration into an GrowthBook.Experiment . Use this function to take the configuration from GrowthBook and convert it into a usable GrowthBook.Experiment struct.","ref":"GrowthBook.Config.html#experiment_from_config/1"},{"type":"function","title":"GrowthBook.Config.feature_rules_from_config/2","doc":"Converts feature rule configuration to a list of feature rules. Use this function to take the configuration retrieved from the /features API endpoint and convert it into a usable list of GrowthBook.FeatureRule structs. This function is used by features_from_config .","ref":"GrowthBook.Config.html#feature_rules_from_config/2"},{"type":"function","title":"GrowthBook.Config.features_from_config/1","doc":"Converts feature configuration to a map of features. Use this function to take the configuration retrieved from the /features API endpoint and convert it into a usable map of GrowthBook.Feature structs.","ref":"GrowthBook.Config.html#features_from_config/1"},{"type":"function","title":"GrowthBook.Config.namespace_from_config/1","doc":"Convert namespace configuration to a namespace. Namespaces are represented by tuples, not lists, in the Elixir SDK, so this function converts a list to the corresponding tuple.","ref":"GrowthBook.Config.html#namespace_from_config/1"},{"type":"type","title":"GrowthBook.Config.json_map/0","doc":"A map with string keys, as returned when decoding JSON using Jason/Poison","ref":"GrowthBook.Config.html#t:json_map/0"},{"type":"module","title":"GrowthBook.Context","doc":"Stores feature and experiment context. Holds the state of features, attributes and other &quot;global&quot; state. The context works similar to %Plug.Conn{} , as it is created for each request and passed along when working with features and experiments.","ref":"GrowthBook.Context.html"},{"type":"function","title":"GrowthBook.Context.get_features/1","doc":"Gets the latest features from the provider function","ref":"GrowthBook.Context.html#get_features/1"},{"type":"type","title":"GrowthBook.Context.attributes/0","doc":"Attributes Attributes are an arbitrary JSON map containing user and request attributes. Here's an example: %{ &quot;id&quot; =&gt; &quot;123&quot; , &quot;anonId&quot; =&gt; &quot;abcdef&quot; , &quot;company&quot; =&gt; &quot;growthbook&quot; , &quot;url&quot; =&gt; &quot;/pricing&quot; , &quot;country&quot; =&gt; &quot;US&quot; , &quot;browser&quot; =&gt; &quot;firefox&quot; , &quot;age&quot; =&gt; 25 , &quot;beta&quot; =&gt; true , &quot;account&quot; =&gt; %{ &quot;plan&quot; =&gt; &quot;team&quot; , &quot;seats&quot; =&gt; 10 } }","ref":"GrowthBook.Context.html#t:attributes/0"},{"type":"type","title":"GrowthBook.Context.features_provider/0","doc":"Function that returns the latest features - a map of %Feature{} structs. Keys are string ids for the features. The function will be called each time features are needed, ensuring the latest features are used. The returned map should be in this format: %{ &quot;feature-1&quot; =&gt; % Feature { default_value : false } , &quot;my_other_feature&quot; =&gt; % Feature { default_value : 1 , rules : [ % FeatureRule { force : 2 } ] } }","ref":"GrowthBook.Context.html#t:features_provider/0"},{"type":"type","title":"GrowthBook.Context.forced_variations/0","doc":"Forced variations map A hash or map that forces an GrowthBook.Experiment to always assign a specific variation. Useful for QA. Keys are the experiment key, values are the list index of the variation. For example: %{ &quot;my-test&quot; =&gt; 0 , &quot;other-test&quot; =&gt; 1 }","ref":"GrowthBook.Context.html#t:forced_variations/0"},{"type":"type","title":"GrowthBook.Context.t/0","doc":"Context Context struct. Has a number of optional properties: enabled? ( boolean/0 ) - Switch to globally disable all experiments. Default true . attributes ( attributes/0 ) - Map of user attributes that are used to assign variations url ( String.t/0 ) - The URL of the current page features_provider ( features_provider/0 ) - Function that returns latest features forced_variations ( forced_variations/0 ) - Force specific experiments to always assign a specific variation (used for QA) qa_mode? ( boolean/0 ) - If true , random assignment is disabled and only explicitly forced variations are used.","ref":"GrowthBook.Context.html#t:t/0"},{"type":"module","title":"GrowthBook.Feature","doc":"Struct holding Feature configuration. Holds the feature's default value, along with the feature's rules.","ref":"GrowthBook.Feature.html"},{"type":"type","title":"GrowthBook.Feature.t/0","doc":"Feature A Feature consists of a default value plus rules that can override the default. default_value ( term/0 ) - The default value (should use nil if not specified) rules (list of GrowthBook.FeatureRule.t/0 ) - List of rules that determine when and how the default_value gets overridden","ref":"GrowthBook.Feature.html#t:t/0"},{"type":"module","title":"GrowthBook.FeatureResult","doc":"Struct holding results of an evaluated Feature. Holds the result of a feature evaluation, and is used to check if a feature is enabled, and optionally what data it provides, if that was configured.","ref":"GrowthBook.FeatureResult.html"},{"type":"function","title":"GrowthBook.FeatureResult.feature_source_from_string/1","doc":"Helper function to convert string sources to atoms","ref":"GrowthBook.FeatureResult.html#feature_source_from_string/1"},{"type":"type","title":"GrowthBook.FeatureResult.source/0","doc":"The source of a feature","ref":"GrowthBook.FeatureResult.html#t:source/0"},{"type":"type","title":"GrowthBook.FeatureResult.t/0","doc":"Feature result The result of evaluating a GrowthBook.Feature . Has a number of keys: value ( term/0 ) - The assigned value of the feature on / on? ( boolean/0 ) - The assigned value cast to a boolean off / off? ( boolean/0 ) - The assigned value cast to a boolean and then negated source ( source/0 ) - The source of the feature result experiment ( GrowthBook.Experiment.t/0 or nil ) - When source is :experiment , this will be an %GrowthBook.Experiment{} struct experiment_result ( GrowthBook.ExperimentResult.t/0 or nil ) - When source is :experiment , this will be an %GrowthBook.ExperimentResult{} struct","ref":"GrowthBook.FeatureResult.html#t:t/0"},{"type":"module","title":"GrowthBook.FeatureRule","doc":"Struct holding Feature rule configuration. Holds rule configuration to determine if a feature should be run, given the active GrowthBook.Context .","ref":"GrowthBook.FeatureRule.html"},{"type":"type","title":"GrowthBook.FeatureRule.t/0","doc":"Feature rule Overrides the default_value of a GrowthBook.Feature . Has a number of optional properties condition ( GrowthBook.Condition.t/0 ) - Optional targeting condition parent_conditions (list of GrowthBook.ParentCondition.t/0 ) - Each item defines a prerequisite where a condition must evaluate against a parent feature's value (identified by id). If gate is true, then this is a blocking feature-level prerequisite; otherwise it applies to the current rule only. coverage ( float/0 ) - What percent of users should be included in the experiment (between 0 and 1, inclusive) force ( term/0 ) - Immediately force a specific value (ignore every other option besides condition and coverage) variations (list of term/0 ) - Run an experiment (A/B test) and randomly choose between these variations key ( String.t/0 ) - The globally unique tracking key for the experiment (default to the feature key) weights (list of float/0 ) - How to weight traffic between variations. Must add to 1. namespace ( GrowthBook.namespace/0 ) - Adds the experiment to a namespace hash_attribute ( String.t/0 ) - What user attribute should be used to assign variations (defaults to id ) hash_version ( integer/0 ) - The hash version to use (default to 1) range ( GrowthBook.BucketRange.t/0 ) - A more precise version of coverage ranges (list of GrowthBook.BucketRange.t/0 ) - Ranges for experiment variations meta (list of GrowthBook.VariationMeta.t/0 ) - Meta info about the experiment variations filters (list of GrowthBook.Filter.t/0 ) - Array of filters to apply to the rule seed ( String.t/0 ) - Seed to use for hashing name ( String.t/0 ) - Human-readable name for the experiment phase ( String.t/0 ) - The phase id of the experiment fallback_attribute ( String.t/0 ) - When using sticky bucketing, can be used as a fallback to assign variations disable_sticky_bucketing ( boolean/0 ) - If true, sticky bucketing will be disabled for this experiment. (Note: sticky bucketing is only available if a StickyBucketingService is provided in the Context) bucket_version ( integer/0 ) - An sticky bucket version number that can be used to force a re-bucketing of users (default to 0) min_bucket_version ( integer/0 ) - Any users with a sticky bucket version less than this will be excluded from the experiment","ref":"GrowthBook.FeatureRule.html#t:t/0"},{"type":"module","title":"GrowthBook.Experiment","doc":"Struct holding Experiment configuration. Holds configuration data for an experiment.","ref":"GrowthBook.Experiment.html"},{"type":"function","title":"GrowthBook.Experiment.from_rule/2","doc":"Creates new experiment struct from rule.","ref":"GrowthBook.Experiment.html#from_rule/2"},{"type":"type","title":"GrowthBook.Experiment.t/0","doc":"Experiment Defines a single Experiment . Has a number of properties: key ( String.t/0 ) - The globally unique identifier for the experiment variations (list of variation/0 ) - The different variations to choose between weights (list of float/0 ) - How to weight traffic between variations. Must add to 1. active? ( boolean/0 ) - If set to false, always return the control (first variation) coverage ( float/0 ) - What percent of users should be included in the experiment (between 0 and 1, inclusive) ranges (list of GrowthBook.BucketRange.t/0 ) - Array of ranges, one per variation condition ( GrowthBook.Condition.t/0 ) - Optional targeting condition namespace ( GrowthBook.namespace/0 ) - Adds the experiment to a namespace force ( integer/0 ) - All users included in the experiment will be forced into the specific variation index hash_attribute ( String.t/0 ) - What user attribute should be used to assign variations (defaults to id) fallback_attribute ( String.t/0 ) - When using sticky bucketing, can be used as a fallback to assign variations hash_version ( integer/0 ) - The hash version to use (default to 1) meta (list of GrowthBook.VariationMeta.t/0 ) - Meta info about the variations filters (list of GrowthBook.Filter.t/0 ) - Array of filters to apply seed ( String.t/0 ) - The hash seed to use name ( String.t/0 ) - Human-readable name for the experiment phase ( String.t/0 ) - Id of the current experiment phase disable_sticky_bucketing ( boolean/0 ) - If true, sticky bucketing will be disabled for this experiment. (Note: sticky bucketing is only available if a StickyBucketingService is provided in the Context) bucket_version ( integer/0 ) - An sticky bucket version number that can be used to force a re-bucketing of users (default to 0) min_bucket_version ( integer/0 ) - Any users with a sticky bucket version less than this will be excluded from the experiment parent_conditions (list of GrowthBook.ParentCondition.t/0 ) - Optional parent conditions","ref":"GrowthBook.Experiment.html#t:t/0"},{"type":"type","title":"GrowthBook.Experiment.variation/0","doc":"Variation Defines a single variation. It may be a map, a number of a string.","ref":"GrowthBook.Experiment.html#t:variation/0"},{"type":"module","title":"GrowthBook.ExperimentResult","doc":"Struct holding the results of an GrowthBook.Experiment . Holds the result of running an GrowthBook.Experiment against a GrowthBook.Context .","ref":"GrowthBook.ExperimentResult.html"},{"type":"type","title":"GrowthBook.ExperimentResult.t/0","doc":"Experiment result The result of running an GrowthBook.Experiment given a specific GrowthBook.Context in_experiment? ( boolean/0 ) - Whether or not the user is part of the experiment variation_id ( integer/0 ) - The array index of the assigned variation value ( any/0 ) - The array value of the assigned variation hash_used? ( boolean/0 ) - If a hash was used to assign a variation hash_attribute ( String.t/0 ) - The user attribute used to assign a variation hash_value ( String.t/0 ) - The value of that attribute feature_id ( String.t/0 ) - The id of the feature (if any) that the experiment came from key ( String.t/0 ) - The unique key for the assigned variation bucket ( float/0 ) - The hash value used to assign a variation (float from 0 to 1) name ( String.t/0 ) - The human-readable name of the assigned variation passthrough? ( boolean/0 ) - Used for holdout groups sticky_bucket_used? ( boolean/0 ) - If sticky bucketing was used to assign a variation The variation_id and value should always be set, even when in_experiment? is false. The hash_attribute and hash_value should always be set, even when hash_used? is false. The key should always be set, even if experiment.meta is not defined or incomplete. In that case, convert the variation's array index to a string (e.g. 0 -&gt; &quot;0&quot;) and use that as the key instead.","ref":"GrowthBook.ExperimentResult.html#t:t/0"},{"type":"module","title":"GrowthBook.BucketRange","doc":"A tuple that describes a range of the numberline between 0 and 1. The tuple has 2 parts, both floats - the start of the range and the end. For example: { 0.3 , 0.7 }","ref":"GrowthBook.BucketRange.html"},{"type":"function","title":"GrowthBook.BucketRange.from_json/1","doc":"","ref":"GrowthBook.BucketRange.html#from_json/1"},{"type":"type","title":"GrowthBook.BucketRange.t/0","doc":"","ref":"GrowthBook.BucketRange.html#t:t/0"},{"type":"module","title":"GrowthBook.Condition","doc":"Functionality for evaluating conditions. You should not (have to) use any of these functions in your own application. They are documented for library developers only. Breaking changes in this module will not be considered breaking changes in the library's public API (or cause a minor/major semver update).","ref":"GrowthBook.Condition.html"},{"type":"function","title":"GrowthBook.Condition.eval_condition/2","doc":"Evaluates a condition against the given attributes. Conditions are MongoDB-query-like expressions. Available expressions: Expression groups $or : Logical OR $nor : Logical OR, but inverted $and : Logical AND $not : Logical NOT Simple expressions $eq : left == right $ne : left != right $lt : left &lt; right $lte : left &lt;= right $gt : left &gt; right $gte : left &gt;= right $exists : (left in [nil, :undefined]) != right $type : typeof left == right $regex : right |&gt; Regex.compile!() |&gt; Regex.match?(left) Array expressions $in : left in right $nin : left not in right $elemMatch : performs the given condition(s) of left for each element of right (with support for expressions) $all : performs the given condition(s) of left for each element of right (without support support for expressions) $size : eval_contition_value(left, length(right)) Version comparison $veq : versions are equal $vne : versions are not equal $vlt : the first version is lesser than the second version $vlte : the first version is lesser than or equal to the second version $vgt : the first version is greater than the second version $vgte : the first version is greater than or equal to the second version Examples iex&gt; GrowthBook.Condition . eval_condition ( %{ &quot;hello&quot; =&gt; &quot;world&quot; } , %{ ...&gt; &quot;hello&quot; =&gt; &quot;world&quot; ...&gt; } ) true iex&gt; GrowthBook.Condition . eval_condition ( %{ &quot;hello&quot; =&gt; &quot;world&quot; } , %{ ...&gt; &quot;hello&quot; =&gt; &quot;optimizely&quot; ...&gt; } ) false","ref":"GrowthBook.Condition.html#eval_condition/2"},{"type":"type","title":"GrowthBook.Condition.condition_value/0","doc":"A condition value","ref":"GrowthBook.Condition.html#t:condition_value/0"},{"type":"type","title":"GrowthBook.Condition.t/0","doc":"Condition A condition is evaluated against GrowthBook.Context.attributes/0 and used to target features/experiments to specific users. The syntax is inspired by MongoDB queries. Here is an example: %{ &quot;country&quot; =&gt; &quot;US&quot; , &quot;browser&quot; =&gt; %{ &quot;$in&quot; =&gt; [ &quot;firefox&quot; , &quot;chrome&quot; ] } , &quot;email&quot; =&gt; %{ &quot;$not&quot; =&gt; %{ &quot;$regex&quot; =&gt; &quot;@gmail.com$&quot; } } }","ref":"GrowthBook.Condition.html#t:t/0"},{"type":"module","title":"GrowthBook.Filter","doc":"Object used for mutual exclusion and filtering users out of experiments based on random hashes. Has the following properties:","ref":"GrowthBook.Filter.html"},{"type":"function","title":"GrowthBook.Filter.from_json/1","doc":"","ref":"GrowthBook.Filter.html#from_json/1"},{"type":"type","title":"GrowthBook.Filter.t/0","doc":"Filter A Filter has the follwing properties: seed ( String.t/0 ) - Teh sedd used in the hash ranges (list of GrowthBook.BucketRange.t/0 ) - List of ranges that are included hash_version ( integer/0 ) - The hash version to use (default to 2) attribute ( String.t/0 ) - The attribute to use (default to &quot;id&quot;)","ref":"GrowthBook.Filter.html#t:t/0"},{"type":"module","title":"GrowthBook.Hash","doc":"","ref":"GrowthBook.Hash.html"},{"type":"function","title":"GrowthBook.Hash.hash/3","doc":"Hashes a string to a float between 0.0 and 1.0 , using the Fowler-Noll-Vo ( fnv32a ) algorithm.","ref":"GrowthBook.Hash.html#hash/3"},{"type":"type","title":"GrowthBook.Hash.seed/0","doc":"","ref":"GrowthBook.Hash.html#t:seed/0"},{"type":"type","title":"GrowthBook.Hash.value/0","doc":"","ref":"GrowthBook.Hash.html#t:value/0"},{"type":"type","title":"GrowthBook.Hash.version/0","doc":"","ref":"GrowthBook.Hash.html#t:version/0"},{"type":"module","title":"GrowthBook.Helpers","doc":"GrowthBook internal helper functions. A collection of helper functions for use internally inside the GrowthBook library. You should not (have to) use any of these functions in your own application. They are documented for library developers only. Breaking changes in this module will not be considered breaking changes in the library's public API (or cause a minor/major semver update).","ref":"GrowthBook.Helpers.html"},{"type":"function","title":"GrowthBook.Helpers.choose_variation/2","doc":"Given a hash and bucket ranges, assign one of the bucket ranges.","ref":"GrowthBook.Helpers.html#choose_variation/2"},{"type":"function","title":"GrowthBook.Helpers.coalesce/1","doc":"","ref":"GrowthBook.Helpers.html#coalesce/1"},{"type":"function","title":"GrowthBook.Helpers.coalesce/2","doc":"","ref":"GrowthBook.Helpers.html#coalesce/2"},{"type":"function","title":"GrowthBook.Helpers.get_bucket_ranges/3","doc":"Converts and experiment's coverage and variation weights into a list of bucket ranges. Examples iex&gt; GrowthBook.Helpers . get_bucket_ranges ( 2 , 1 , [ 0.5 , 0.5 ] ) [ { 0.0 , 0.5 } , { 0.5 , 1.0 } ] iex&gt; GrowthBook.Helpers . get_bucket_ranges ( 2 , 0.5 , [ 0.4 , 0.6 ] ) [ { 0.0 , 0.2 } , { 0.4 , 0.7 } ]","ref":"GrowthBook.Helpers.html#get_bucket_ranges/3"},{"type":"function","title":"GrowthBook.Helpers.get_equal_weights/1","doc":"Returns an list of floats with count items that are all equal and sum to 1. Examples iex&gt; GrowthBook.Helpers . get_equal_weights ( 2 ) [ 0.5 , 0.5 ]","ref":"GrowthBook.Helpers.html#get_equal_weights/1"},{"type":"function","title":"GrowthBook.Helpers.get_query_string_override/3","doc":"Checks if an experiment variation is being forced via a URL query string. Examples iex&gt; GrowthBook.Helpers . get_query_string_override ( &quot;my-test&quot; , &quot;http://localhost/?my-test=1&quot; , 2 ) 1 iex&gt; GrowthBook.Helpers . get_query_string_override ( &quot;my-test&quot; , &quot;not valid&quot; , 2 ) nil","ref":"GrowthBook.Helpers.html#get_query_string_override/3"},{"type":"function","title":"GrowthBook.Helpers.in_namespace?/2","doc":"This checks if a userId is within an experiment namespace or not.","ref":"GrowthBook.Helpers.html#in_namespace?/2"},{"type":"function","title":"GrowthBook.Helpers.in_range?/2","doc":"Determines if a number n is within the provided range.","ref":"GrowthBook.Helpers.html#in_range?/2"},{"type":"function","title":"GrowthBook.Helpers.included_in_rollout?/6","doc":"Determines if the user is part of a gradual feature rollout.","ref":"GrowthBook.Helpers.html#included_in_rollout?/6"},{"type":"module","title":"GrowthBook.ParentCondition","doc":"A ParentCondition defines a prerequisite. Instead of evaluating against attributes, the condition evaluates against the returned value of the parent feature. The condition will always reference a &quot;value&quot; property. Here is an example of a gating prerequisite where the parent feature must be toggled on: % ParentCondition { id : &quot;parent-feature&quot; , condition : %{ &quot;value&quot; : { &quot;$exists&quot; : true } } , gate : true }","ref":"GrowthBook.ParentCondition.html"},{"type":"function","title":"GrowthBook.ParentCondition.eval/3","doc":"","ref":"GrowthBook.ParentCondition.html#eval/3"},{"type":"function","title":"GrowthBook.ParentCondition.from_json/1","doc":"","ref":"GrowthBook.ParentCondition.html#from_json/1"},{"type":"type","title":"GrowthBook.ParentCondition.error/0","doc":"","ref":"GrowthBook.ParentCondition.html#t:error/0"},{"type":"type","title":"GrowthBook.ParentCondition.t/0","doc":"ParentCondition A ParentCondition consists of a parent feature's id (string), a condition (Condition), and an optional gate (boolean) flag. id ( String.t/0 ) - parent feature's id condition ( GrowthBook.Condition.t/0 ) - condition gate ( boolean/0 ) - If gate is true, then this is a blocking feature-level prerequisite; otherwise it applies to the current rule only.","ref":"GrowthBook.ParentCondition.html#t:t/0"},{"type":"module","title":"GrowthBook.VariationMeta","doc":"Meta info about an experiment variation.","ref":"GrowthBook.VariationMeta.html"},{"type":"function","title":"GrowthBook.VariationMeta.from_json/1","doc":"","ref":"GrowthBook.VariationMeta.html#from_json/1"},{"type":"type","title":"GrowthBook.VariationMeta.t/0","doc":"VariationMeta Has the following properties: key ( String.t/0 ) - A unique key for this variation (optional) name ( String.t/0 ) - A human-readable name for this variation (optional) passthrough? ( boolean/0 ) - Used to implement holdout groups (optional)","ref":"GrowthBook.VariationMeta.html#t:t/0"},{"type":"exception","title":"GrowthBook.ParentCondition.CyclingError","doc":"","ref":"GrowthBook.ParentCondition.CyclingError.html"},{"type":"type","title":"GrowthBook.ParentCondition.CyclingError.t/0","doc":"","ref":"GrowthBook.ParentCondition.CyclingError.html#t:t/0"},{"type":"exception","title":"GrowthBook.ParentCondition.PrerequisiteError","doc":"","ref":"GrowthBook.ParentCondition.PrerequisiteError.html"},{"type":"type","title":"GrowthBook.ParentCondition.PrerequisiteError.t/0","doc":"","ref":"GrowthBook.ParentCondition.PrerequisiteError.html#t:t/0"}]